@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.026_001'; # TRIAL VERSION
+our $VERSION = '0.026_002'; # TRIAL VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
@@ -553,14 +553,12 @@ Defines what to do when a cyclic reference is detected when loading.
 
 =item duplicate_keys
 
-Default: 1
+Default: 0
 
-Since version 0.026
+Since version 0.027
 
 This option is for loading.
 
-NOTE: THIS OPTION WILL BE SET TO 0 IN THE NEXT RELEASE.
-
 The YAML Spec says duplicate mapping keys should be forbidden.
 
 When set to true, duplicate keys in mappings are allowed (and will overwrite
@@ -605,7 +603,7 @@ Default: 1
 
 This option is for dumping.
 
-Print document heaader C<--->
+Print document header C<--->
 
 =item footer
 
@@ -733,7 +731,7 @@ with this code:
 Then dumping it will return the same output.
 Only folded block scalars '>' cannot preserve the style yet.
 
-Note that YAML allows repeated definition of anchors. They cannot bw preserved
+Note that YAML allows repeated definition of anchors. They cannot be preserved
 with YAML::PP right now. Example:
 
     ---
@@ -761,8 +759,8 @@ a scalar, the object will be replaced by a simple scalar.
 You can also pass C<1> as a value. In this case all preserving options will be
 enabled, also if there are new options added in the future.
 
-There are also methods to craete preserved nodes from scratch. See the
-C<preserved_(scalar|mapping|sequence> L<"METHODS"> below.
+There are also methods to create preserved nodes from scratch. See the
+C<preserved_(scalar|mapping|sequence)> L<"METHODS"> below.
 
 =back
 
@@ -1195,7 +1193,7 @@ they will be dumped with double quotes.
 It will recognize JSON::PP::Boolean and boolean.pm objects and dump them
 correctly.
 
-Numbers which also have a PV flag will be recognized as numbers and not
+Numbers which also have a C<PV> flag will be recognized as numbers and not
 as strings:
 
     my $int = 23;
