@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Constructor;
 
-our $VERSION = '0.026_001'; # TRIAL VERSION
+our $VERSION = '0.026_002'; # TRIAL VERSION
 
 use YAML::PP;
 use YAML::PP::Common qw/
@@ -21,10 +21,9 @@ sub new {
     my ($class, %args) = @_;
 
     my $default_yaml_version = delete $args{default_yaml_version};
-    # TODO: switch to default 0
     my $duplicate_keys = delete $args{duplicate_keys};
     unless (defined $duplicate_keys) {
-        $duplicate_keys = 1;
+        $duplicate_keys = 0;
     }
     my $preserve = delete $args{preserve} || 0;
     if ($preserve == 1) {
@@ -323,11 +322,11 @@ sub alias_event {
             my $cyclic_refs = $self->cyclic_refs;
             if ($cyclic_refs ne 'allow') {
                 if ($cyclic_refs eq 'fatal') {
-                    die "Found cyclic ref";
+                    die "Found cyclic ref for alias '$name'";
                 }
                 if ($cyclic_refs eq 'warn') {
                     $anchor = { data => \undef };
-                    warn "Found cyclic ref";
+                    warn "Found cyclic ref for alias '$name'";
                 }
                 elsif ($cyclic_refs eq 'ignore') {
                     $anchor = { data => \undef };
@@ -336,6 +335,9 @@ sub alias_event {
         }
         $value = $anchor->{data};
     }
+    else {
+        croak "No anchor defined for alias '$name'";
+    }
     my $last = $self->stack->[-1];
     push @{ $last->{ref} }, $$value;
 }
